JsonForms class

Constructors

JsonForms(Map<String, dynamic> dataSchemaJson, Map<String, dynamic> uiSchemaJson, Map<String, dynamic> dataJson, JsonFormsCallback callback)

Properties

callback → JsonFormsCallback
final
data ↔ Map<String, dynamic>
getter/setter pair
dataSchema ↔ JsonSchema4
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiSchema ↔ UISchemaElement
getter/setter pair

Methods

createWidgets(UISchemaElement schema, BuildContext context, List<Widget> widgets) → List<Widget>
getControl(UISchemaElement uiSchema, JsonSchema4 schema, BuildContext context) → Widget
getItem(List<String> parts, JsonSchema4 schema) → JsonSchema4
getWidget(BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited