JsonSchema4 class

Constructors

JsonSchema4({String? id, String? $schema, String? title, String? description, String? type, List<String>? required, Map<String, JsonSchema4>? properties, JsonSchema4? items, List<JsonSchema4>? allOf, List<JsonSchema4>? anyOf, List<JsonSchema4>? oneOf, JsonSchema4? not, dynamic defaultValue, List? enumValues, String? format, bool? readOnly, bool? writeOnly, bool? deprecated, num? multipleOf, num? maximum, bool? exclusiveMaximum, num? minimum, bool? exclusiveMinimum, int? maxLength, int? minLength, String? pattern, int? maxItems, int? minItems, bool? uniqueItems, int? maxProperties, int? minProperties, Map<String, JsonSchema4>? definitions, Map<String, JsonSchema4>? patternProperties, Map<String, JsonSchema4>? dependencies, JsonSchema4? additionalProperties, JsonSchema4? additionalItems, JsonSchema4? propertyNames, JsonSchema4? contains, JsonSchema4? constValue, List<JsonSchema4>? examples, Map<String, dynamic>? extensions})
JsonSchema4.fromJson(Map<String, dynamic> json)
factory

Properties

$schema ↔ String?
getter/setter pair
additionalItems ↔ JsonSchema4?
getter/setter pair
additionalProperties ↔ JsonSchema4?
getter/setter pair
allOf ↔ List<JsonSchema4>?
getter/setter pair
anyOf ↔ List<JsonSchema4>?
getter/setter pair
constValue ↔ JsonSchema4?
getter/setter pair
contains ↔ JsonSchema4?
getter/setter pair
defaultValue ↔ dynamic
getter/setter pair
definitions ↔ Map<String, JsonSchema4>?
getter/setter pair
dependencies ↔ Map<String, JsonSchema4>?
getter/setter pair
deprecated ↔ bool?
getter/setter pair
description ↔ String?
getter/setter pair
enumValues ↔ List?
getter/setter pair
examples ↔ List<JsonSchema4>?
getter/setter pair
exclusiveMaximum ↔ bool?
getter/setter pair
exclusiveMinimum ↔ bool?
getter/setter pair
extensions ↔ Map<String, dynamic>?
getter/setter pair
format ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
items ↔ JsonSchema4?
getter/setter pair
maximum ↔ num?
getter/setter pair
maxItems ↔ int?
getter/setter pair
maxLength ↔ int?
getter/setter pair
maxProperties ↔ int?
getter/setter pair
minimum ↔ num?
getter/setter pair
minItems ↔ int?
getter/setter pair
minLength ↔ int?
getter/setter pair
minProperties ↔ int?
getter/setter pair
multipleOf ↔ num?
getter/setter pair
not ↔ JsonSchema4?
getter/setter pair
oneOf ↔ List<JsonSchema4>?
getter/setter pair
pattern ↔ String?
getter/setter pair
patternProperties ↔ Map<String, JsonSchema4>?
getter/setter pair
properties ↔ Map<String, JsonSchema4>?
getter/setter pair
propertyNames ↔ JsonSchema4?
getter/setter pair
readOnly ↔ bool?
getter/setter pair
required ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
uniqueItems ↔ bool?
getter/setter pair
writeOnly ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited