ControlElement class

Inheritance

Constructors

ControlElement({String? type, String? scope, List<UISchemaElement>? elements, String? label, String? text, Map<String, dynamic>? options})
ControlElement.fromJson(Map<String, dynamic> json)
factory

Properties

elements ↔ List<UISchemaElement>?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
getter/setter pairinherited
options ↔ Map<String, dynamic>?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pairinherited
text ↔ String?
getter/setter pairinherited
type ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited