UISchemaElement class

Implementers

Constructors

UISchemaElement({String? type, String? scope, List<UISchemaElement>? elements, String? label, String? text, Map<String, dynamic>? options})
UISchemaElement.fromJson(Map<String, dynamic> json)
factory

Properties

elements ↔ List<UISchemaElement>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
getter/setter pair
options ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pair
text ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited